==> haskell-cryptonite-conduit-0.2.0-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.0
id: cryptonite-conduit-0.2.0-DoouCNkUApo31vxKA9f54e
key: cryptonite-conduit-0.2.0-DoouCNkUApo31vxKA9f54e
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.MAC.HMAC.Conduit Crypto.Hash.Conduit
abi: 0501aa7b7cd6d8a75a70cb42c989d8dc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptonite-conduit-0.2.0
hs-libraries: HScryptonite-conduit-0.2.0-DoouCNkUApo31vxKA9f54e
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.15-6XNZLygDeFX2HjFkbmIzsS
    cryptonite-0.22-DUE2wxQoCnxGJxqhoLxB9Z
    memory-0.14.5-8bv3NC3SoYTKu3JUzoaHbd
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptonite-conduit-0.2.0-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.0
id: cryptonite-conduit-0.2.0-CnleWyRm5iyKvs6QQwBK6
key: cryptonite-conduit-0.2.0-CnleWyRm5iyKvs6QQwBK6
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.MAC.HMAC.Conduit Crypto.Hash.Conduit
abi: 6c97c1af55835b43897e3b1fa6cfbd00
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptonite-conduit-0.2.0
hs-libraries: HScryptonite-conduit-0.2.0-CnleWyRm5iyKvs6QQwBK6
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.15-6XNZLygDeFX2HjFkbmIzsS
    cryptonite-0.22-BghVPg0sVunAfXbG7gt71d
    memory-0.14.5-GKVoAxUgmX27c6UFr57XrL
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
